==> 0.0.1.tar.gz: lib/src/feature/initSDK/ui/init_chhotastocks_widget.dart <==
import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/config/chhota_stocks_config.dart';
import 'package:chhota_stocks_flutter/src/core/config/flavour.dart';
import 'package:chhota_stocks_flutter/src/core/core.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/loader.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/splash.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/bloc/discover_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/bloc/init_sdk_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/ui/home_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/bloc/aggregated_bloc/aggregated_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/bloc/portfolio_summary/portfolio_summary_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_localizations/flutter_localizations.dart';


final chhotaStocksNavigatorKey = GlobalKey<NavigatorState>();


class InitChhotaStocksWidget extends StatefulWidget {
  final String partnerGatewayName;
  final String partnerGatewaySecret;
  final String mobile;
  final String? languageCode;

  final ChhotaStocksFlavour chhotaStocksFlavour;
  final VoidCallback onDone;

  const InitChhotaStocksWidget({Key? key,required this.partnerGatewayName,
    required this.partnerGatewaySecret,required this.chhotaStocksFlavour,required this.onDone,required this.mobile,this.languageCode="en"}):super(key: key);
  @override
  _InitChhotaStocksWidgetState createState() => _InitChhotaStocksWidgetState();
}

class _InitChhotaStocksWidgetState extends State<InitChhotaStocksWidget> {
  @override
  void initState(){
    super.initState();

    ///Initialising Chhota Stocks SDK
    ChhotaStocksConfig.initChhotaStocksConfig(
        partnerGatewayName: widget.partnerGatewayName,
        languageCode: widget.languageCode ?? "en",
        partnerGatewaySecret: widget.partnerGatewaySecret,
        chhotaStocksFlavour: widget.chhotaStocksFlavour,
        mobile: widget.mobile);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        theme: ChhotaStocksTheme.lightThemeData,
        debugShowCheckedModeBanner: false,
        //  locale:  Locale(ChhotaStocksConfig.getInstance().languageCode,""),
        locale:   Locale(widget.languageCode??"en",""),
        navigatorKey: chhotaStocksNavigatorKey,
        supportedLocales: const [
          Locale('en', ''), //Engish
          Locale('hi', ''), //Hindi
          Locale('kn', ''), //Kannada
          Locale('te', ''), //Telugu
          Locale('ta', ''), //Tamil
          Locale('ml', ''), //Malayalam
          Locale('mr', ''), //Marathi
          Locale('gu', ''), //Gujarati
          Locale('bn', ''), //Bangla
          Locale('pa', ''), //Punjabi
          Locale('or', ''), //Odia
          Locale('ur', ''), //Urdu
        ],
        localizationsDelegates:const [
          Translations.delegate, // Add this line
          GlobalMaterialLocalizations.delegate,
          GlobalWidgetsLocalizations.delegate,
          GlobalCupertinoLocalizations.delegate,
        ],
        home: SplashScreen(onFinish: widget.onDone,));
    return InitSDKWidget(onDone: widget.onDone,);
  }
}


class InitSDKWidget extends StatefulWidget {
  final VoidCallback? onDone;
  const InitSDKWidget({Key? key, this.onDone}) : super(key: key);

  @override
  State<InitSDKWidget> createState() => _InitSDKWidgetState();
}

class _InitSDKWidgetState extends State<InitSDKWidget> {

  @override
  Widget build(BuildContext context) {
    return Material(

      child: WillPopScope(
        onWillPop: ()async{
          return false;
        },
        child: MultiBlocProvider(
          providers: [
            BlocProvider<InitSdkCubit>(create: (_)=>InitSdkCubit(),),
            BlocProvider<DiscoverCubit>(create: (_)=>DiscoverCubit(),),
            BlocProvider<AggregatedCubit>(create: (_)=>AggregatedCubit()),
            BlocProvider<PortfolioSummaryCubit>(create: (_)=>PortfolioSummaryCubit()),

          ],

          child:_InitSDKWidget(onDone: widget.onDone,),
        ),
      ),
    );
  }
}

class _InitSDKWidget extends StatefulWidget {
  final VoidCallback? onDone;
  const _InitSDKWidget({Key? key, this.onDone}) : super(key: key);
  @override
  __InitSDKWidgetState createState() => __InitSDKWidgetState();
}

class __InitSDKWidgetState extends State<_InitSDKWidget> {
  @override
  void initState() {
    super.initState();
    context.read<InitSdkCubit>().initSDK();
  }

  @override
  Widget build(BuildContext context) {


    return BlocConsumer<InitSdkCubit,InitSdkState>(

        builder: (context,state){
          if(state is InitSdkSuccess){
            return HomeWidget(onDone: widget.onDone,);
          }else if(state  is  InitSdkFailed){
            return const ChhotaStocksErrorWidget();
          }

          return const Loader();


        },
        listener: (context,state)async{
          if(state is InitSdkSuccess){
            debugPrint("Chhota Stocks SDK:initialised");
          }else if(state is InitSdkFailed){
            Navigator.pop(context);
            debugPrint("Init sdk failed.");
          }
        });
  }
}

==> 0.0.2.tar.gz: lib/src/feature/initSDK/ui/init_chhotastocks_widget.dart <==
import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/config/chhota_stocks_config.dart';
import 'package:chhota_stocks_flutter/src/core/config/flavour.dart';
import 'package:chhota_stocks_flutter/src/core/core.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/loader.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/splash.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/bloc/discover_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/funds/bloc/funds_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/bloc/init_sdk_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/ui/home_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/bloc/aggregated_bloc/aggregated_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/bloc/portfolio_summary/portfolio_summary_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_localizations/flutter_localizations.dart';


//final chhotaStocksNavigatorKey = GlobalKey<NavigatorState>();


class InitChhotaStocksWidget extends StatefulWidget {
  final String partnerGatewayName;
  final String partnerGatewaySecret;
  final String mobile;
  final String? languageCode;

  final ChhotaStocksFlavour chhotaStocksFlavour;
  final VoidCallback onDone;

  const InitChhotaStocksWidget({Key? key,required this.partnerGatewayName,
    required this.partnerGatewaySecret,required this.chhotaStocksFlavour,required this.onDone,required this.mobile,this.languageCode="en"}):super(key: key);
  @override
  _InitChhotaStocksWidgetState createState() => _InitChhotaStocksWidgetState();
}

class _InitChhotaStocksWidgetState extends State<InitChhotaStocksWidget> {
  @override
  void initState(){
    super.initState();

    ///Initialising Chhota Stocks SDK
    ChhotaStocksConfig.initChhotaStocksConfig(
        partnerGatewayName: widget.partnerGatewayName,
        languageCode: widget.languageCode ?? "en",
        partnerGatewaySecret: widget.partnerGatewaySecret,
        chhotaStocksFlavour: widget.chhotaStocksFlavour,
        mobile: widget.mobile);
  }

  @override
  Widget build(BuildContext context) {

    return MaterialApp(
        theme: ChhotaStocksTheme.lightThemeData,
        debugShowCheckedModeBanner: false,
        locale:  Locale(ChhotaStocksConfig.getInstance().languageCode,""),
        //navigatorKey: chhotaStocksNavigatorKey,
        supportedLocales: const [
          Locale('en', ''), //Engish
          Locale('hi', ''), //Hindi
          Locale('kn', ''), //Kannada
          Locale('te', ''), //Telugu
          Locale('ta', ''), //Tamil
          Locale('ml', ''), //Malayalam
          Locale('mr', ''), //Marathi
          Locale('gu', ''), //Gujarati
          Locale('bn', ''), //Bangla
          Locale('pa', ''), //Punjabi
          Locale('or', ''), //Odia
          Locale('ur', ''), //Urdu
        ],
        localizationsDelegates:const [
          Translations.delegate, // Add this line
          GlobalMaterialLocalizations.delegate,
          GlobalWidgetsLocalizations.delegate,
          GlobalCupertinoLocalizations.delegate,
        ],
        home: SplashScreen(onFinish: widget.onDone,));

  }
}


class InitSDKWidget extends StatefulWidget {
  final VoidCallback? onDone;
  const InitSDKWidget({Key? key, this.onDone}) : super(key: key);

  @override
  State<InitSDKWidget> createState() => _InitSDKWidgetState();
}

class _InitSDKWidgetState extends State<InitSDKWidget> {

  @override
  Widget build(BuildContext context) {
    return Material(

      child: MultiBlocProvider(
        providers: [
          BlocProvider<InitSdkCubit>(create: (_)=>InitSdkCubit(),),
          BlocProvider<DiscoverCubit>(create: (_)=>DiscoverCubit(),),
          BlocProvider<AggregatedCubit>(create: (_)=>AggregatedCubit()),
          BlocProvider<PortfolioSummaryCubit>(create: (_)=>PortfolioSummaryCubit()),
          BlocProvider<FundsCubit>(
              create: (context) => FundsCubit()),

        ],

        child:_InitSDKWidget(onDone: widget.onDone,),
      ),
    );
  }
}

class _InitSDKWidget extends StatefulWidget {
  final VoidCallback? onDone;
  const _InitSDKWidget({Key? key, this.onDone}) : super(key: key);
  @override
  __InitSDKWidgetState createState() => __InitSDKWidgetState();
}

class __InitSDKWidgetState extends State<_InitSDKWidget> {
  @override
  void initState() {
    super.initState();
    BlocProvider.of<InitSdkCubit>(context).initSDK();
  }

  @override
  Widget build(BuildContext context) {


    return BlocConsumer<InitSdkCubit,InitSdkState>(

        builder: (context,state){
          if(state is InitSdkSuccess){
            return HomeWidget(onDone: widget.onDone,);
          }else if(state is InitSdkUserDoesNotExist){
            return const  Center(child: Text("User Does not Exist"),);
          }else if(state  is  InitSdkFailed){
            return Theme(
                data: ChhotaStocksTheme.lightThemeData,
                child: const ChhotaStocksErrorWidget());
          }

          return const Loader();


        },
        listener: (context,state)async{
          if(state is InitSdkSuccess){
            debugPrint("Chhota Stocks SDK:initialised");
          }else if(state is InitSdkFailed){
            debugPrint("Init sdk failed.");
          }
        });
  }
}
